summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--rules.js9
1 files changed, 6 insertions, 3 deletions
diff --git a/rules.js b/rules.js
index 1a36bea..d197ec4 100644
--- a/rules.js
+++ b/rules.js
@@ -3846,12 +3846,15 @@ function set_active_to_next_combat_power() {
set_active_to_current_sequence_of_play()
if (is_intro() || is_two_player())
return
// resolve all austria combat first
if (game.power === P_AUSTRIA) {
for (let i = 0; i < game.combat.length; i += 2) {
let p = get_supreme_commander(game.combat[i])
- if (p >= 0 && piece_power[p] === P_AUSTRIA)
- return
+ if (p >= 0) {
+ let pp = piece_power[p]
+ if (pp === P_AUSTRIA || pp === P_SAXONY)
+ return
+ }
}
set_active_to_power(P_PRAGMATIC)
}
@@ -3846,12 +3846,15 @@ function set_active_to_next_combat_power() {
if (is_intro() || is_two_player())
return
- // resolve all austria combat first
+ // resolve all austria (& saxony) combat first; then pragmatic
if (game.power === P_AUSTRIA) {
for (let i = 0; i < game.combat.length; i += 2) {